:root{--djai-tab-bg:#4383a3;--djai-tab-bg--active:var(--primary);--djai-tab-bg--hover:var(--primary);--djai-tab-fg:var(--primary-fg);--djai-tab-fg--active:var(--primary-fg);--djai-tab-fg--hover:var(--primary-fg);--djai-dropdown-bg:var(--secondary);--djai-dropdown-bg--active:var(--primary);--djai-dropdown-bg--hover:var(--primary);--djai-dropdown-fg:var(--header-link-color);--djai-tablist-spacing-top:10px;--djai-nav-sidebar-offset:84px}#container{min-height:100%;height:auto}#main{z-index:1}#header{z-index:2}.calendarbox,.clockbox{z-index:1}#nav-sidebar{top:var(--djai-nav-sidebar-offset)}#header{top:var(--djai-header-offset,0);position:sticky;overflow:visible}:root{--djai-tab-bg:#4383a3;--djai-tab-bg--active:var(--primary);--djai-tab-bg--hover:var(--primary);--djai-tab-fg:var(--primary-fg);--djai-tab-fg--active:var(--primary-fg);--djai-tab-fg--hover:var(--primary-fg);--djai-dropdown-bg:var(--secondary);--djai-dropdown-bg--active:var(--primary);--djai-dropdown-bg--hover:var(--primary);--djai-dropdown-fg:var(--header-link-color);--djai-tablist-spacing-top:10px;--djai-nav-sidebar-offset:84px}.djai-dropdown-menu{margin-top:var(--djai-tablist-spacing-top);flex-basis:100%;display:block}#header{flex-wrap:wrap;padding-bottom:0}.djai-dropdown-menu .djai-dropdown-menu__item{background-color:var(--djai-tab-bg);cursor:pointer;padding:10px;display:inline-block;position:relative}.djai-dropdown-menu .djai-dropdown-menu__item,.djai-dropdown-menu .djai-dropdown-menu__item:link,.djai-dropdown-menu .djai-dropdown-menu__item:visited{color:var(--djai-tab-fg)}.djai-dropdown-menu .djai-dropdown-menu__item--active{background-color:var(--djai-tab-bg--active)}.djai-dropdown-menu .djai-dropdown-menu__item--active,.djai-dropdown-menu .djai-dropdown-menu__item--active:link,.djai-dropdown-menu .djai-dropdown-menu__item--active:visited{color:var(--djai-tab-fg--active);text-decoration:none}.djai-dropdown-menu .djai-dropdown-menu__item:hover,.djai-dropdown-menu .djai-dropdown-menu__item:focus{background-color:var(--djai-tab-bg--hover)}.djai-dropdown-menu .djai-dropdown-menu__item:hover,.djai-dropdown-menu .djai-dropdown-menu__item:hover:link,.djai-dropdown-menu .djai-dropdown-menu__item:hover:visited,.djai-dropdown-menu .djai-dropdown-menu__item:focus,.djai-dropdown-menu .djai-dropdown-menu__item:focus:link,.djai-dropdown-menu .djai-dropdown-menu__item:focus:visited{color:var(--djai-tab-fg--hover);text-decoration:none!important}.djai-dropdown-menu .djai-dropdown-menu__item:hover .djai-dropdown-menu__drop,.djai-dropdown-menu .djai-dropdown-menu__item:focus .djai-dropdown-menu__drop{display:block}.djai-dropdown-menu .djai-dropdown-menu__drop{min-width:150px;z-index:1;max-height:75vh;background-color:var(--djai-dropdown-bg);display:none;position:absolute;top:100%;left:0;overflow-y:auto;box-shadow:0 4px 8px #0003,0 6px 20px #0003}.djai-dropdown-menu .djai-dropdown-menu__drop-item{background-color:#0000}.djai-dropdown-menu .djai-dropdown-menu__drop-item--active{background-color:var(--djai-dropdown-bg--active)}.djai-dropdown-menu .djai-dropdown-menu__drop-item:hover,.djai-dropdown-menu .djai-dropdown-menu__drop-item:focus{background-color:var(--djai-dropdown-bg--hover)}#header .djai-dropdown-menu .djai-dropdown-menu__drop-item a,#header .djai-dropdown-menu .djai-dropdown-menu__drop-item a:link,#header .djai-dropdown-menu .djai-dropdown-menu__drop-item a:visited{color:var(--djai-dropdown-fg)}#header .djai-dropdown-menu .djai-dropdown-menu__drop-item a:hover{text-decoration:none}.djai-dropdown-menu .djai-dropdown-menu__link{padding:10px;display:block}@media (max-width:767px){.breadcrumbs{z-index:1;position:relative}.djai-dropdown-menu{align-self:flex-start}.djai-dropdown-menu .djai-dropdown-menu__item{margin-top:3px}}
/*# sourceMappingURL=admin-index.css.map */
