# Generated by Django 3.0.8 on 2020-07-24 15:16

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("admin_index", "0002_auto_20170802_1754"),
    ]

    operations = [
        migrations.AlterField(
            model_name="appgroup",
            name="order",
            field=models.PositiveIntegerField(
                db_index=True, editable=False, verbose_name="order"
            ),
        ),
        migrations.AlterField(
            model_name="applink",
            name="order",
            field=models.PositiveIntegerField(
                db_index=True, editable=False, verbose_name="order"
            ),
        ),
    ]
