/*
The header is the container for our admin-index menu dropdown, which we make
visible at all times. For this, the header itself needs to receive a position fixed or
sticky so that it stays in view when scrolling down vertically.

If the header itself is sticky and the container for the dropdowns, we don't need to
mess with height offsets relative to the header/branding - which may not be pixel-
perfect because of font-rendering shenanigans.
*/

#header {
  position: sticky;
  top: var(--djai-header-offset, 0);
  // the dropdown menu is a child and overflows
  overflow: visible;
}
