{% extends "admin/change_form.html" %}
{% load i18n admin_urls static django_admin_index %}

{% block extrastyle %}{{ block.super }}
<link rel="stylesheet" href="{% static "admin/css/admin-index.css" %}">{% endblock %}

{% block nav-global %}{% include "django_admin_index/includes/app_list.html" %}{% endblock nav-global %}

{% if not is_popup %}
{% block breadcrumbs %}
{% admin_index_settings as admin_index_settings %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
{# NOTE: Remove app groups if needed #}
{% if not admin_index_settings.HIDE_APP_INDEX_PAGES %}
    &rsaquo;
    <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
{% endif %}
{% block breadcrumbs_pre_changelist %}{% endblock %}
&rsaquo; {% if has_view_permission %}<a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>{% else %}{{ opts.verbose_name_plural|capfirst }}{% endif %}
&rsaquo; {% if add %}{% blocktrans with name=opts.verbose_name %}Add {{ name }}{% endblocktrans %}{% else %}{{ original|truncatewords:"18" }}{% endif %}
</div>
{% endblock %}
{% endif %}
