{% extends "registration/password_change_done.html" %}
{% load static django_admin_index %}

{% block extrastyle %}{{ block.super }}
<link rel="stylesheet" href="{% static "admin/css/admin-index.css" %}">{% endblock %}

{% block nav-global %}{% include "django_admin_index/includes/app_list.html" %}{% endblock nav-global %}
